import type * as vite from 'vite';
import type { AstroConfig, ComponentInstance, Renderer, RouteData, RuntimeMode } from '../../../@types/astro';
import { LogOptions } from '../../logger.js';
import { RouteCache } from '../route-cache.js';
interface SSROptions {
    /** an instance of the AstroConfig */
    astroConfig: AstroConfig;
    /** location of file on disk */
    filePath: URL;
    /** logging options */
    logging: LogOptions;
    /** "development" or "production" */
    mode: RuntimeMode;
    /** production website, needed for some RSS & Sitemap functions */
    origin: string;
    /** the web request (needed for dynamic routes) */
    pathname: string;
    /** optional, in case we need to render something outside of a dev server */
    route?: RouteData;
    /** pass in route cache because SSR can’t manage cache-busting */
    routeCache: RouteCache;
    /** Vite instance */
    viteServer: vite.ViteDevServer;
}
export declare type ComponentPreload = [Renderer[], ComponentInstance];
export declare function preload({ astroConfig, filePath, viteServer }: Pick<SSROptions, 'astroConfig' | 'filePath' | 'viteServer'>): Promise<ComponentPreload>;
/** use Vite to SSR */
export declare function render(renderers: Renderer[], mod: ComponentInstance, ssrOpts: SSROptions): Promise<string>;
export declare function ssr(preloadedComponent: ComponentPreload, ssrOpts: SSROptions): Promise<string>;
export {};
